Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1151)

Unified Diff: chrome/browser/ui/fullscreen_controller.h

Issue 10261011: Windowed mode mouse lock addded to fullscreen controller. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: indent Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/fullscreen_controller.h
diff --git a/chrome/browser/ui/fullscreen_controller.h b/chrome/browser/ui/fullscreen_controller.h
index ea79a51a01c6c1e76793a7ea5057869448715a9c..99ca65176dea5ed17d27fcc670ee9810390a12f8 100644
--- a/chrome/browser/ui/fullscreen_controller.h
+++ b/chrome/browser/ui/fullscreen_controller.h
@@ -92,13 +92,15 @@ class FullscreenController : public base::RefCounted<FullscreenController> {
virtual ~FullscreenController();
- // Notifies the tab that it has been forced out of fullscreen mode if
- // necessary.
- void NotifyTabOfFullscreenExitIfNecessary();
- // Make the current tab exit fullscreen mode if it is in it.
- void ExitTabbedFullscreenModeIfNecessary();
+ // Notifies the tab that it has been forced out of fullscreen and mouse lock
+ // mode if necessary.
+ void NotifyTabOfExitIfNecessary();
+
+ // Make the current tab exit fullscreen mode or mouse lock if it is in it.
+ void ExitTabFullscreenOrMouseLockIfNecessary();
void UpdateFullscreenExitBubbleContent();
void NotifyFullscreenChange();
+ void NotifyMouseLockChange();
ContentSetting GetFullscreenSetting(const GURL& url) const;
ContentSetting GetMouseLockSetting(const GURL& url) const;
@@ -125,6 +127,12 @@ class FullscreenController : public base::RefCounted<FullscreenController> {
// clicking the allow button on the fullscreen infobar.
bool tab_fullscreen_accepted_;
+ // True if this controller has toggled into tab OR browser fullscreen.
+ bool toggled_into_fullscreen_;
+
+ // Wrapper for current tab requesting or currently in mouse lock.
+ TabContentsWrapper* mouse_lock_tab_;
+
MouseLockState mouse_lock_state_;
DISALLOW_COPY_AND_ASSIGN(FullscreenController);
« no previous file with comments | « chrome/browser/ui/cocoa/fullscreen_exit_bubble_controller.mm ('k') | chrome/browser/ui/fullscreen_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698